@@ -10,9 +10,14 @@ from collections import abc
 from enum import Enum
 from functools import wraps
 from typing import cast, ClassVar, Mapping, Union, Optional, Any, Callable, \
-    Tuple, Protocol
+    Tuple
 from urllib.parse import urljoin, quote
 
+try:
+    from typing import Protocol
+except ImportError:
+    from typing_extensions import Protocol
+
 import requests
 import attr
 from attr import attrs, fields_dict, NOTHING
