@@ -383,6 +383,34 @@ def _validate_scope_query(data: CpdPathData) -> None:
 
 @attr.attrs(auto_attribs=True, frozen=True)
 class CpdPath:
+    """
+    Path to CPD scope or some resource within one.
+
+    Scopes:
+
+    * ``[cpd://[<context>]]/(projects|spaces|catalogs)/<scope-id>``
+    * ``[cpd://[<context>]]/(projects|spaces|catalogs)?<query-string>]``
+
+      * `name` - a scope name
+      * `tags` - a list of resource tags (comma separated)
+
+    Resources:
+
+    * ``[cpd://[<context>]]/(projects|spaces|catalogs)/<scope-id>/<resource-type>/<resource-ID>``
+    * ``[cpd://[<context>]]/(projects|spaces|catalogs)/<scope-id>/<resource-type>?<query-string>``
+
+      * `name` - a resource name
+      * `tags` - a list of resource tags (comma separated)
+      * `rev` - a resource revision (if supported by a given resource type)
+      * `asset_type` - an asset type (only for assets)
+      * `datasource_type` - a datasource name (only for connection assets, eg. "bluemixcloudobjectstorage", "db2", "redshift")
+
+    Files:
+
+    * ``[cpd://[<context>]]/(projects|spaces|catalogs)/<scope-id>/files/<file-path>``
+    * ``[cpd://[<context>]]/(projects|spaces|catalogs)/<scope-id>/connections/<connection-id>/files/<bucket-name>/<file-path>``
+    """
+
     data: CpdPathData
 
     def __str__(self) -> str:
@@ -390,6 +418,11 @@ class CpdPath:
 
     @classmethod
     def from_string(cls: Type[Self], path: str) -> Self:
+        """
+        Parse the path from some string. This is the preferred method of creating CPD-Paths.
+
+        Note that different subclasses will be created from different kinds of paths.
+        """
         # creates different kinds of CpdPath depending on path
         data = CpdPathData.from_string(path)
 
@@ -412,19 +445,66 @@ class CpdPath:
             raise TypeError(f"Uknown kind of CpdPath: {str(data)}")
 
     def context(self) -> Optional[str]:
+        """
+        Return the ``context`` part of the CPD-Path, if any.
+
+        Example::
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789")
+            assert path.context() == "dev"
+
+            path = CpdPath.from_string("cpd:///projects/123456789")
+            assert path.context() is None
+        """
         return self.data.ctx
 
     def scope_type(self) -> Optional[str]:
+        """
+        Return the scope type, if any.
+
+        Example::
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789")
+            assert path.scope_type() == "projects"
+
+            path = CpdPath.from_string("assets/3141592")
+            assert path.scope_type() is None
+        """
         if self.data.path.scope is None:
             return None
         return self.data.path.scope.type.value
 
     def scope_id(self) -> Optional[str]:
+        """
+        Return the scope ID, if any.
+
+        Example::
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789")
+            assert path.scope_id() == "123456789"
+
+            path = CpdPath.from_string("cpd://dev/projects?name=foobar")
+            assert path.scope_id() is None
+
+            path = CpdPath.from_string("assets/3141592")
+            assert path.scope_id() is None
+        """
         if self.data.path.scope is None:
             return None
         return self.data.path.scope.id
 
     def query(self) -> Optional[str]:
+        """
+        Return the query party, if any.
+
+        Example::
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789")
+            assert path.query() is None
+
+            path = CpdPath.from_string("cpd://dev/projects?name=foobar")
+            assert path.query() == "name=foobar"
+        """
         query_obj = self.data.query
         query_str = ""
         if query_obj:
@@ -449,10 +529,32 @@ class CpdScope(CpdPathImpl):
 
 class CpdScopeFile(CpdScope):
     def file_path(self) -> str:
+        """
+        Extract the file path.
+
+        Example::
+
+            file_path = CpdPath.from_string("cpd://dev/projects/123456789/files/abc/def")
+            assert file_path.file_path() == "/abc/def"
+
+            file_path = CpdPath.from_string("cpd://dev/projects/123456789/connections/3141592/files/~/abc/def")
+            assert file_path.file_path() == "/abc/def"
+        """
+
         return  "/" + self.data.path.file.path
 
 class CpdResource(CpdPathImpl):
     def scope(self) -> Optional[CpdScope]:
+        """
+        Extract the scope path, if any.
+
+        Example::
+
+            scope_path = CpdPath.from_string("cpd://dev/projects/123456789")
+            resource_path = CpdPath.from_string("cpd://dev/projects/123456789/connections/3141592")
+            assert resource_path.scope() == scope_path
+        """
+
         if self.data.path.scope is None:
             return None
         return CpdScope(
@@ -469,9 +571,28 @@ class CpdResource(CpdPathImpl):
         )
 
     def resource_type(self) -> str:
+        """
+        Return the resource type.
+
+        Example::
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789/connections/3141592")
+            assert path.resource_type() == "connections"
+        """
         return self.data.path.resource.type.value
 
     def resource_id(self) -> Optional[str]:
+        """
+        Return the resource ID, if any.
+
+        Example::
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789/connections/3141592")
+            assert path.resource_id() == "3141592"
+
+            path = CpdPath.from_string("cpd://dev/projects/123456789/connections?name=foobar")
+            assert path.resource_id() is None
+        """
         return self.data.path.resource.id
 
 class CpdConnectionFile(CpdResource):
@@ -480,6 +601,14 @@ class CpdConnectionFile(CpdResource):
         return super().resource_id()
 
     def bucket_name(self) -> str:
+        """
+        Extract the bucket name.
+
+        Example::
+
+            file_path = CpdPath.from_string("cpd://dev/projects/123456789/connections/3141592/files/~/abc/def")
+            assert file_path.bucket_name() == "~"
+        """
         path = self.data.path.file.path
         parts = path.split("/")
         return parts[0]
